@@ -1,7 +1,7 @@
 # ----------- Logging ------------
 
 package Audio::Nama::Log;
-use Modern::Perl;
+use Modern::Perl '2020';
 use Log::Log4perl qw(get_logger :levels);
 use Exporter;
 use Carp qw(carp cluck confess croak);
@@ -17,31 +17,34 @@ Audio::Nama::AnalyseLV2
 Audio::Nama::Assign
 Audio::Nama::Bunch
 Audio::Nama::Bus
+Audio::Nama::BusUtil
 Audio::Nama::CacheTrack
 Audio::Nama::ChainSetup
 Audio::Nama::Config
 Audio::Nama::Custom
+Audio::Nama::EcasoundCleanup
+Audio::Nama::EcasoundRun
+Audio::Nama::EcasoundSetup
 Audio::Nama::Edit
 Audio::Nama::EffectChain
-Audio::Nama::Effects
+Audio::Nama::EffectNickname
+Audio::Nama::Effect
 Audio::Nama::EffectsRegistry
 Audio::Nama::Engine
-Audio::Nama::EngineCleanup
-Audio::Nama::EngineRun
 Audio::Nama::EngineSetup
 Audio::Nama::Fade
 Audio::Nama::Git
 Audio::Nama::Globals
 Audio::Nama::Grammar
-Audio::Nama::Graph
 Audio::Nama::Graphical
+Audio::Nama::Graph
 Audio::Nama::Help
-Audio::Nama::IO
 Audio::Nama::Initializations
 Audio::Nama::Insert
+Audio::Nama::IO
 Audio::Nama::Jack
-Audio::Nama::Lat
 Audio::Nama::Latency
+Audio::Nama::Lat
 Audio::Nama::Log
 Audio::Nama::Mark
 Audio::Nama::Memoize
@@ -53,17 +56,27 @@ Audio::Nama::Nama
 Audio::Nama::Object
 Audio::Nama::Options
 Audio::Nama::Persistence
-Audio::Nama::Plug
 Audio::Nama::Project
-Audio::Nama::RegionComp
 Audio::Nama::Regions
 Audio::Nama::Sequence
+Audio::Nama::StatusSnapshot
+Audio::Nama::Tempo
 Audio::Nama::Terminal
 Audio::Nama::Text
+Audio::Nama::TrackComment
+Audio::Nama::TrackEffect
+Audio::Nama::TrackIO
+Audio::Nama::TrackLatency
+Audio::Nama::TrackMark
 Audio::Nama::Track
+Audio::Nama::TrackRegion
+Audio::Nama::TrackUtils
+Audio::Nama::TrackWaveform
 Audio::Nama::Util
-Audio::Nama::Wav
+Audio::Nama::Waveform
 Audio::Nama::Wavinfo
+Audio::Nama::WavModify
+Audio::Nama::Wav
 
 	);
 	push @all_cats, 'ECI','SUB';
