@@ -4,7 +4,7 @@
 # grammar_body.pl with subroutines in Grammar.p
 
 package Audio::Nama::Text;
-use Modern::Perl; use Carp;
+use Modern::Perl '2020'; use Carp;
 no warnings 'uninitialized';
 use Audio::Nama::Globals qw(:all);
 use Audio::Nama::Assign qw(:all);
@@ -16,13 +16,15 @@ sub hello {"hello world!";}
 
 sub loop {
 	package Audio::Nama;
-	issue_first_prompt();
+	initialize_prompt();
 	$Event::DIED = sub {
-	   my ($event, $errmsg) = @_;
-	   say $errmsg;
-	   $text->{term_attribs}->{line_buffer} = q();
-	   $text->{term}->clear_message();
-	   $text->{term}->rl_reset_line_state();
+		my ($event, $errmsg) = @_;
+		throw($errmsg);
+		$text->{term_attribs}->{line_buffer} = q();
+		if($term){
+			$term->clear_message();
+			$term->rl_reset_line_state();
+		}
 	};
 	use Data::Dumper::Concise;
 	Event::loop();
@@ -64,6 +66,7 @@ sub paint_mute_buttons {}
 sub remove_track_gui {}
 sub reset_engine_mode_color_display {}
 sub set_engine_mode_color_display {}
+sub setup_playback_indicator {}
 
 1;
 __END__
\ No newline at end of file
